/*
 * digital_clock_mode.cc
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "digital_clock_mode.h"
#include "common.h"
#include "text.h"
#include "text_renderer.h"
#include "time.h"
#include "Arduino.h"


void DigitalClockMode::draw( int segment )
{
	Text::draw( 0, segment );
	Text::draw( 1, segment );
}


void DigitalClockMode::draw_reset()
{
	PString str0( Text::_messages[ 0 ], MESSAGE_LEN * 4 );
	str0.begin();

	switch( _flavour )
	{
	case 0:
		str0.format( "%d%c%02d %s", Time::get_hours() % 12,
			::millis() % 1000 < 500? ':' : '.',
			Time::get_minutes(),
			Time::get_hours() >= 12? "pm" : "am" );
		break;
	case 1:
		str0.format( "%d%s %s, %d", Time::get_day(),
				Time::get_day_suffix(),
				Time::get_month_name(), Time::get_year() );
		break;
	}

	Text::set_message( 0, str0 );
}


void DigitalClockMode::activate()
{
	_flavour = 0;

	reset_messages();
}


void DigitalClockMode::press()
{
	if( ++_flavour >= 2 )
		_flavour = 0;

	reset_messages();
}


void DigitalClockMode::reset_messages()
{
	switch( _flavour )
	{
	case 0:
		Text::reset_message( 0, Text::MODE_TOP | Text::MODE_ALL,
				Text::SCALE_FAT);
		break;
	case 1:
		Text::reset_message( 0, Text::MODE_HSCROLL | Text::MODE_TOP |
				Text::MODE_THREEQUARTERS );
		break;
	}
}
