/*
 * switcher_major_mode.cc
 *
 * Copyright (C) 2012 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "switcher_major_mode.h"
#include "analogue_clock_mode.h"
#include "digital_clock_mode.h"
#include "info_mode.h"
#include "test_pattern_mode.h"
#include "../text.h"
#include "../common.h"


SwitcherMajorMode::SwitcherMajorMode()
{
	static AnalogueClockMode analogue_clock;
	static DigitalClockMode digital_clock;
	static InfoMode info;
//	static TestPatternMode test_pattern;

	// add modes to list
	int mode = 0;
	_modes[ mode++ ] = &analogue_clock;
	_modes[ mode++ ] = &digital_clock;
	_modes[ mode++ ] = &info;
//	_modes[ mode++ ] = &test_pattern;

	// finish the list
	_modes[ mode ] = 0;
}


void SwitcherMajorMode::draw( int segment )
{
	_modes[ _mode ]->draw( segment );
}


void SwitcherMajorMode::draw_reset()
{
	_modes[ _mode ]->draw_reset();
}


void SwitcherMajorMode::activate()
{
	// reset text
	Text::reset();
	leds_off();

	_mode = 0;
	_modes[ _mode ]->activate();
}


void SwitcherMajorMode::deactivate()
{
	_modes[ _mode ]->deactivate();
}


void SwitcherMajorMode::press()
{
	_modes[ _mode ]->press();
}


void SwitcherMajorMode::long_press()
{
	_modes[ _mode ]->deactivate();

	// inc mode
	if( !_modes[ ++_mode ] ) _mode = 0;

	// reset text
	Text::reset();
	leds_off();

	_modes[ _mode ]->activate();
}
