/*
 * text.h
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _TEXT_H_
#define _TEXT_H_


#include <PString.h>


#define NUM_MESSAGE_BUFFERS 4
#define MESSAGE_LEN 32


namespace Text
{
	enum {
		// one of these to select face
		MODE_TOP = 1,
		MODE_BOTTOM = 0,

		// one of these to select size
		MODE_ONEQUARTER = 0,
		MODE_ONETHIRD = 4,
		MODE_HALF = 8,
		MODE_TWOTHIRDS = 12,
		MODE_THREEQUARTERS = 16,
		MODE_ALL = 20,

		// flag to turn on horizontal scrolling
		MODE_HSCROLL = 32,
	};

	enum {
		SCALE_VSMALL = 1,
		SCALE_SMALL = 2,
		SCALE_NORMAL = 3,
		SCALE_FAT = 4,
		SCALE_VFAT = 5,
	};

	/**
	 * After modifying a message buffer, call this to reset the internal state
	 * of the text renderer with regard to this message.
	 *
	 * @param message_num the buffer number
	 * @param pstring the PString that represents this message's buffer
	 */
	void set_message( int message_num, PString &pstring );

	/**
	 * Reset the display of a message and specify its display parameters.
	 *
	 * @param message_num the message to reset
	 * @param mode the new mode for this message
	 * @param scale text
	 */
	void reset_message( int message_num, char mode, int scale = SCALE_NORMAL );

	/**
	 * Reset internal state, for a new text display.
	 */
	void reset();

	/**
	 * Call at the start of each frame.
	 */
	void draw_reset();

	/**
	 * Call after drawing each frame
	 */
	void post_draw();

	/**
	 * Draw segment for the specified message number using whatever mode that
	 * message is set to.
	 *
	 * @param message_num the message buffer number
	 * @param segment to draw
	 */
	void draw( int message_num, int segment );

	/** internal message buffers */
	extern char _messages[ NUM_MESSAGE_BUFFERS ][ MESSAGE_LEN ];
};


#endif //_TEXT_H_
